@@ -12,6 +12,7 @@
 # Copyright: Red Hat Inc. 2021
 # Authors: Jan Richter <jarichte@redhat.com>
 
+import logging
 import os
 import time
 
@@ -316,9 +317,23 @@ class LogMessageHandler(BaseRunningMessageHandler):
     :type log: string
     :param time: Time stamp of the message
     :type time: float
+    :param log_name: optional name of the logger, such as "avocado.test.foo"
+    :type log_name: string
+    :param log_levelname: level of the logger, such as "INFO", required
+                          if "log_name" is set
+    :type log_levelname: string
+    :param log_message: message formatted as message only (no name, level
+                        or timestamp), require if "log_name" is set
+    :type log_message: string
 
     example: {'status': 'running', 'type': 'log', 'log': 'log message',
-             'time': 18405.55351474}
+              'time': 18405.55351474}
+
+    or:
+
+    example: {'status': 'running', 'type': 'log', 'log': 'log message',
+              'time': 18405.55351474, 'log_name': 'avocado.test.foo',
+              'log_levelname': 'INFO', 'log_message': 'foo content'}
     """
 
     _tag = b"[stdlog] "
@@ -335,61 +350,80 @@ class LogMessageHandler(BaseRunningMessageHandler):
             )
         self._save_to_default_file(message, task)
 
+        # For messages from specific loggers, we preserve their names
+        # and levels so that they are handled appropriately based on
+        # the Avocado job logging configuration
+        log_name = message.get("log_name")
+        if log_name is not None:
+            logger = logging.getLogger(log_name)
+            level = logging.getLevelName(message.get("log_levelname"))
+            logger.log(level, message.get("log_message"))
+
 
 class StdoutMessageHandler(BaseRunningMessageHandler):
     """
     Handler for stdout message.
 
-    It will save the stdout to the stdout and debug file in the task directory.
+    It will save the stdout to the debug file in the task directory,
+    and optionally (depending on "log_only" value) to the stdout file.
 
     :param status: 'running'
     :param type: 'stdout'
     :param log: stdout message
     :type log: bytes
+    :param log_only: whether to save the "log" message only to the standard
+                     test log (and not to the "stdout" file)
+    :type log_only: bool
     :param encoding: optional value for decoding messages
     :type encoding: str
     :param time: Time stamp of the message
     :type time: float
 
     example: {'status': 'running', 'type': 'stdout', 'log': 'stdout message',
-             'time': 18405.55351474}
+              'log_only': False, 'time': 18405.55351474}
     """
 
     _tag = b"[stdout] "
 
     def handle(self, message, task, job):
         self._save_to_default_file(message, task)
-        self._save_message_to_file(
-            "stdout", message["log"], task, message.get("encoding", None)
-        )
+        if not message.get("log_only", False):
+            self._save_message_to_file(
+                "stdout", message["log"], task, message.get("encoding", None)
+            )
 
 
 class StderrMessageHandler(BaseRunningMessageHandler):
     """
     Handler for stderr message.
 
-    It will save the stderr to the stderr and debug file in the task directory.
+    It will save the stderr to the debug file in the task directory,
+    and optionally (depending on "log_only" value) to the stderr file.
 
     :param status: 'running'
     :param type: 'stderr'
     :param log: stderr message
     :type log: bytes
+    :param log_only: whether to save the "log" message only to the standard
+                     test log (and not to the "stderr" file)
+    :type log_only: bool
     :param encoding: optional value for decoding messages
     :type encoding: str
     :param time: Time stamp of the message
     :type time: float
 
     example: {'status': 'running', 'type': 'stderr', 'log': 'stderr message',
-             'time': 18405.55351474}
+              'log_only': False, 'time': 18405.55351474}
     """
 
     _tag = b"[stderr] "
 
     def handle(self, message, task, job):
         self._save_to_default_file(message, task)
-        self._save_message_to_file(
-            "stderr", message["log"], task, message.get("encoding", None)
-        )
+        if not message.get("log_only", False):
+            self._save_message_to_file(
+                "stderr", message["log"], task, message.get("encoding", None)
+            )
 
 
 class WhiteboardMessageHandler(BaseRunningMessageHandler):
