@@ -252,7 +252,7 @@ class FetchAssetJob(JobPreTests):  # pylint: disable=R0903
     name = "fetchasset"
     description = "Fetch assets before the test run"
 
-    def __init__(self, config=None):
+    def __init__(self, config=None):  # pylint: disable=W0231
         pass
 
     def pre_tests(self, job):
@@ -272,13 +272,8 @@ class FetchAssetJob(JobPreTests):  # pylint: disable=R0903
                         module_path, klass_method = test.uri.split(":", 1)
                         klass, method = klass_method.split(".", 1)
                         candidate = (module_path, klass, method)
-                        candidates.append(candidate)
-
-                # fetch assets only on instrumented tests
-                elif isinstance(test[0], str):
-                    candidate = (test[1]["modulePath"], test[0], test[1]["methodName"])
-                    if candidate not in candidates:
-                        candidates.append(candidate)
+                        if candidate not in candidates:
+                            candidates.append(candidate)
 
         for candidate in candidates:
             fetch_assets(*candidate, logger)
