@@ -33,6 +33,7 @@ class TestFail(AssertionError, Exception):
 
     This is here, just because of an impossible circular import.
     """
+
     status = "FAIL"
 
 
@@ -51,6 +52,7 @@ def fail_on_dmesg(level=5):
     :return: Class decorator
     :rtype: class
     """
+
     def dmesg_fail(cls):
         def raise_dmesg_fail(func):
             @wraps(func)
@@ -61,12 +63,14 @@ def fail_on_dmesg(level=5):
                     return data
                 except DmesgError as details:
                     raise TestFail(repr(details)) from details
+
             return wrapper
 
         for key, value in list(vars(cls).items()):
-            if callable(value) and value.__name__.startswith('test'):
+            if callable(value) and value.__name__.startswith("test"):
                 setattr(cls, key, raise_dmesg_fail(value))
         return cls
+
     return dmesg_fail
 
 
@@ -77,11 +81,11 @@ def clear_dmesg():
     This function needs sudo permissions enabled on the target host
     """
     cmd = "dmesg -c"
-    status = process.system(cmd, timeout=30, ignore_status=True,
-                            verbose=False, shell=True, sudo=True)
+    status = process.system(
+        cmd, timeout=30, ignore_status=True, verbose=False, shell=True, sudo=True
+    )
     if status:
-        raise DmesgError(
-            "Unable to clear dmesg as some issue while clearing")
+        raise DmesgError("Unable to clear dmesg as some issue while clearing")
 
 
 def collect_dmesg(output_file=None):
@@ -97,10 +101,10 @@ def collect_dmesg(output_file=None):
     :rtype: str
     """
     if output_file is None:
-        _, output_file = tempfile.mkstemp(suffix=f".-{time.strftime('%Y-%m-%d:%H:%M:%S')}",
-                                          dir=tempfile.gettempdir())
-    dmesg = process.system_output(
-        "dmesg", ignore_status=True, sudo=True).decode()
+        _, output_file = tempfile.mkstemp(
+            suffix=f".-{time.strftime('%Y-%m-%d:%H:%M:%S')}", dir=tempfile.gettempdir()
+        )
+    dmesg = process.system_output("dmesg", ignore_status=True, sudo=True).decode()
     genio.write_file(output_file, dmesg)
     if not os.path.isfile(output_file):
         raise DmesgError(f"{output_file} is not a valid file.")
@@ -141,10 +145,8 @@ def collect_errors_by_level(output_file=None, level_check=5, skip_errors=None):
     if not isinstance(level_check, int):
         raise DmesgError("level_check param should be integer")
     dmsg_log = ""
-    cmd = (f"dmesg -T -l {','.join(map(str, range(0, int(level_check))))}"
-           f"|grep .")
-    out = process.run(cmd, timeout=30, ignore_status=True,
-                      verbose=False, shell=True)
+    cmd = f"dmesg -T -l {','.join(map(str, range(0, int(level_check))))}" f"|grep ."
+    out = process.run(cmd, timeout=30, ignore_status=True, verbose=False, shell=True)
     if out.exit_status == 0:
         err = "Found failures in dmesg"
         if skip_errors:
@@ -153,7 +155,7 @@ def collect_errors_by_level(output_file=None, level_check=5, skip_errors=None):
             dmsg_log = f"dmesg log:\n{out.stdout_text}"
     if dmsg_log:
         if output_file:
-            with open(output_file, "w+", encoding='utf-8') as log_f:
+            with open(output_file, "w+", encoding="utf-8") as log_f:
                 log_f.write(dmsg_log)
             err += f" Please check  dmesg log {output_file}."
         else:
@@ -165,18 +167,17 @@ def collect_errors_by_level(output_file=None, level_check=5, skip_errors=None):
 def skip_dmesg_messages(dmesg_stdout, skip_messages):
     """Remove some messages from a dmesg buffer.
 
-      This method will remove some lines in a dmesg buffer if some strings are
-      present. Returning the same buffer, but with less lines (in case of match).
+    This method will remove some lines in a dmesg buffer if some strings are
+    present. Returning the same buffer, but with less lines (in case of match).
 
-      :dmesg_stdout: dmesg messages from which filter should be applied. This
-                     must be a decoded output buffer with new lines.
-      :type dmesg_stdout: str
-      :skip_messages: list of strings to be removed
-      :type skip_messages: list
+    :dmesg_stdout: dmesg messages from which filter should be applied. This
+                   must be a decoded output buffer with new lines.
+    :type dmesg_stdout: str
+    :skip_messages: list of strings to be removed
+    :type skip_messages: list
     """
+
     def filter_strings(line):
         return not any([string in line for string in skip_messages])
 
-    return '\n'.join(filter(None,
-                            filter(filter_strings,
-                                   dmesg_stdout.splitlines())))
+    return "\n".join(filter(None, filter(filter_strings, dmesg_stdout.splitlines())))
