@@ -267,11 +267,19 @@ class CentOSImageProvider(ImageProviderBase):
         self.url_images = self.url_versions + "{version}/images/"
         self.image_pattern = "CentOS-(?P<version>{version})-(?P<arch>{arch})-GenericCloud-(?P<build>{build}).qcow2.xz$"
 
-    def get_image_url(self):
+    def _set_patterns(self):
         if int(self.version) >= 8:
             self.build = r"[\d\.\-]+"
             self.url_images = self.url_versions + "{version}/{arch}/images/"
             self.image_pattern = "CentOS-(?P<version>{version})-GenericCloud-(?P<build>{build}).(?P<arch>{arch}).qcow2$"
+
+    @property
+    def file_name(self):
+        self._set_patterns()
+        return super().file_name
+
+    def get_image_url(self):
+        self._set_patterns()
         return super().get_image_url()
 
 
@@ -582,7 +590,7 @@ class Image:
             cache_dirs=cache_dirs,
             expire=None,
             metadata=metadata,
-        ).fetch()
+        ).fetch(timeout=asset.DOWNLOAD_TIMEOUT * 3)
 
         if archive.is_archive(asset_path):
             uncompressed_path = os.path.splitext(asset_path)[0]
