@@ -24,17 +24,17 @@ class MagicRunner(BaseRunner):
 
     def run(self, runnable):
         yield StartedMessage.get()
-        if runnable.uri in ['pass', 'fail']:
+        if runnable.uri in ["pass", "fail"]:
             result = runnable.uri
         else:
-            result = 'error'
+            result = "error"
         yield FinishedMessage.get(result)
 
 
 class RunnerApp(BaseRunnerApp):
-    PROG_NAME = 'avocado-runner-magic'
-    PROG_DESCRIPTION = 'nrunner application for magic tests'
-    RUNNABLE_KINDS_CAPABLE = ['magic']
+    PROG_NAME = "avocado-runner-magic"
+    PROG_DESCRIPTION = "nrunner application for magic tests"
+    RUNNABLE_KINDS_CAPABLE = ["magic"]
 
 
 def main():
@@ -42,5 +42,5 @@ def main():
     app.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
