@@ -17,22 +17,20 @@ class CAbort(Test):
         """
         Build 'abort'.
         """
-        source = self.params.get('source', default='abort.c')
+        source = self.params.get("source", default="abort.c")
         c_file = self.get_data(source)
         if c_file is None:
-            self.cancel(f'Test is missing data file {source}')
+            self.cancel(f"Test is missing data file {source}")
         c_file_name = os.path.basename(c_file)
         dest_c_file = os.path.join(self.workdir, c_file_name)
         shutil.copy(c_file, dest_c_file)
-        build.make(self.workdir,
-                   env={'CFLAGS': '-g -O0'},
-                   extra_args='abort')
+        build.make(self.workdir, env={"CFLAGS": "-g -O0"}, extra_args="abort")
 
     def test(self):
         """
         Execute 'abort'.
         """
-        cmd = os.path.join(self.workdir, 'abort')
+        cmd = os.path.join(self.workdir, "abort")
         cmd_result = process.run(cmd, ignore_status=True)
         self.log.info(cmd_result)
         expected_result = -6  # SIGABRT = 6
