@@ -13,25 +13,22 @@ class Plant(Test):
 
         # Preparing soil
         for row in range(rows):
-            progress_log.info("%s: preparing soil on row %s",
-                              self.name, row)
+            progress_log.info("%s: preparing soil on row %s", self.name, row)
 
         # Letting soil rest
-        progress_log.info("%s: letting soil rest before throwing seeds",
-                          self.name)
+        progress_log.info("%s: letting soil rest before throwing seeds", self.name)
         time.sleep(1)
 
         # Throwing seeds
         for row in range(rows):
-            progress_log.info("%s: throwing seeds on row %s",
-                              self.name, row)
+            progress_log.info("%s: throwing seeds on row %s", self.name, row)
 
         # Let them grow
-        progress_log.info("%s: waiting for Avocados to grow",
-                          self.name)
+        progress_log.info("%s: waiting for Avocados to grow", self.name)
         time.sleep(2)
 
         # Harvest them
         for row in range(rows):
-            progress_log.info("%s: harvesting organic avocados on row %s",
-                              self.name, row)
+            progress_log.info(
+                "%s: harvesting organic avocados on row %s", self.name, row
+            )
